@@ -1,10 +1,11 @@
-from .config import Config
 from .basic import cell_co_occurrence, cell_components, cell_density, cell_morphology
-from .ext import prepare_svca
-from .preprocessing import read_ROIs
+from .config import Config
+from .data_info import list_roi, make_roi_unique
+from .preprocessing import read_images, read_visium
 from .spatial import (
     cell_dispersion,
     cell_interaction,
+    cell_community,
     find_neighbors,
     GCNG,
     NCD_marker,
@@ -15,11 +16,13 @@ from .spatial import (
     spatial_coexp,
     spatial_enrichment,
     spatial_heterogeneity,
+    spatial_weights,
 )
-from .utils import get_result, transform_points, transform_shapes
-
+from .utils import get_result, wkt_points, wkt_shapes
 from ._version import version_tuple
+
 __version__ = ".".join([str(i) for i in version_tuple[:3]])
 
 import logging
-logging.getLogger("lightning").setLevel(logging.ERROR)
\ No newline at end of file
+
+logging.getLogger("lightning").setLevel(logging.ERROR)
